==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_HtmlContainerCell.h <==
//----------------------------------------------------------------------------
// wxHtmlContainerCell
// extracted from htcontnr.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_HTMLCONTAINERCELL_H__
#define __CLASS_WX_HTMLCONTAINERCELL_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxHtmlContainerCell
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_HtmlContainerCell);

//----------------------------------------------------------------------------
// Object declaration for wxHtmlContainerCell
//----------------------------------------------------------------------------
class Object_wx_HtmlContainerCell : public Object_wx_HtmlCell {
public:
	Gura_DeclareObjectAccessor(wx_HtmlContainerCell)
public:
	inline Object_wx_HtmlContainerCell(wxHtmlContainerCell *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_HtmlCell(Gura_UserClass(wx_HtmlContainerCell), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_HtmlContainerCell(Class *pClass, wxHtmlContainerCell *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_HtmlCell(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_HtmlContainerCell();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxHtmlContainerCell *GetEntity() {
		return dynamic_cast<wxHtmlContainerCell *>(_pEntity);
	}
	inline wxHtmlContainerCell *ReleaseEntity() {
		wxHtmlContainerCell *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxHtmlContainerCell");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_HtmlContainerCell.h <==
//----------------------------------------------------------------------------
// wxHtmlContainerCell
// extracted from htcontnr.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_HTMLCONTAINERCELL_H__
#define __CLASS_WX_HTMLCONTAINERCELL_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxHtmlContainerCell
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_HtmlContainerCell);

//----------------------------------------------------------------------------
// Object declaration for wxHtmlContainerCell
//----------------------------------------------------------------------------
class Object_wx_HtmlContainerCell : public Object_wx_HtmlCell {
public:
	Gura_DeclareObjectAccessor(wx_HtmlContainerCell)
public:
	inline Object_wx_HtmlContainerCell(wxHtmlContainerCell *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_HtmlCell(Gura_UserClass(wx_HtmlContainerCell), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_HtmlContainerCell(Class *pClass, wxHtmlContainerCell *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_HtmlCell(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_HtmlContainerCell();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxHtmlContainerCell *GetEntity() {
		return dynamic_cast<wxHtmlContainerCell *>(_pEntity);
	}
	inline wxHtmlContainerCell *ReleaseEntity() {
		wxHtmlContainerCell *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxHtmlContainerCell");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
